<?php
/**
 * Factora theme customizer
 *
 * @package Factora
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Factora_Customize {
	/**
	 * Customize settings
	 *
	 * @var array
	 */
	protected $config = array();

	/**
	 * The class constructor
	 *
	 * @param array $config
	 */
	public function __construct( $config ) {
		$this->config = $config;

		if ( ! class_exists( 'Kirki' ) ) {
			return;
		}

		$this->register();
	}

	/**
	 * Register settings
	 */
	public function register() {

		/**
		 * Add the theme configuration
		 */
		if ( ! empty( $this->config['theme'] ) ) {
			Kirki::add_config(
				$this->config['theme'], array(
					'capability'  => 'edit_theme_options',
					'option_type' => 'theme_mod',
				)
			);
		}

		/**
		 * Add panels
		 */
		if ( ! empty( $this->config['panels'] ) ) {
			foreach ( $this->config['panels'] as $panel => $settings ) {
				Kirki::add_panel( $panel, $settings );
			}
		}

		/**
		 * Add sections
		 */
		if ( ! empty( $this->config['sections'] ) ) {
			foreach ( $this->config['sections'] as $section => $settings ) {
				Kirki::add_section( $section, $settings );
			}
		}

		/**
		 * Add fields
		 */
		if ( ! empty( $this->config['theme'] ) && ! empty( $this->config['fields'] ) ) {
			foreach ( $this->config['fields'] as $name => $settings ) {
				if ( ! isset( $settings['settings'] ) ) {
					$settings['settings'] = $name;
				}

				Kirki::add_field( $this->config['theme'], $settings );
			}
		}
	}

	/**
	 * Get config ID
	 *
	 * @return string
	 */
	public function get_theme() {
		return $this->config['theme'];
	}

	/**
	 * Get customize setting value
	 *
	 * @param string $name
	 *
	 * @return bool|string
	 */
	public function get_option( $name ) {

		$default = $this->get_option_default( $name );

		return get_theme_mod( $name, $default );
	}

	/**
	 * Get default option values
	 *
	 * @param $name
	 *
	 * @return mixed
	 */
	public function get_option_default( $name ) {
		if ( ! isset( $this->config['fields'][ $name ] ) ) {
			return false;
		}

		return isset( $this->config['fields'][ $name ]['default'] ) ? $this->config['fields'][ $name ]['default'] : false;
	}
}

/**
 * This is a short hand function for getting setting value from customizer
 *
 * @param string $name
 *
 * @return bool|string
 */
function factora_get_option( $name ) {
	global $factora_customize;

	$value = false;

	if ( class_exists( 'Kirki' ) ) {
		$value = Kirki::get_option( 'factora', $name );
	} elseif ( ! empty( $factora_customize ) ) {
		$value = $factora_customize->get_option( $name );
	}

	return apply_filters( 'factora_get_option', $value, $name );
}

/**
 * Get default option values
 *
 * @param $name
 *
 * @return mixed
 */
function factora_get_option_default( $name ) {
	global $factora_customize;

	if ( empty( $factora_customize ) ) {
		return false;
	}

	return $factora_customize->get_option_default( $name );
}

/**
 * Move some default sections to `general` panel that registered by theme
 *
 * @param object $wp_customize
 */
function factora_customize_modify( $wp_customize ) {
	$wp_customize->get_section( 'title_tagline' )->panel     = 'general';
	$wp_customize->get_section( 'static_front_page' )->panel = 'general';
}

add_action( 'customize_register', 'factora_customize_modify' );

/**
 * Get customize settings
 *
 * @return array
 */
function factora_customize_settings() {
	/**
	 * Customizer configuration
	 */

	$settings = array(
		'theme' => 'factora',
	);

	$panels = array(
		'general'     => array(
			'priority' => 5,
			'title'    => esc_html__( 'General', 'factora' ),
		),
		'typography'  => array(
			'priority' => 10,
			'title'    => esc_html__( 'Typography', 'factora' ),
		),
		'styling'     => array(
			'priority' => 10,
			'title'    => esc_html__( 'Styling', 'factora' ),
		),
		'header'      => array(
			'title'      => esc_html__( 'Header', 'factora' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
		'page_header' => array(
			'title'      => esc_html__( 'Page Header', 'factora' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
		'blog'        => array(
			'title'      => esc_html__( 'Blog', 'factora' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
		'page'        => array(
			'title'      => esc_html__( 'Page', 'factora' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
		'portfolio'   => array(
			'title'    => esc_html__( 'Portfolio', 'factora' ),
			'priority' => 10,
		),
		'service'     => array(
			'title'    => esc_html__( 'Service', 'factora' ),
			'priority' => 10,
		),
		'testimonial' => array(
			'title'    => esc_html__( 'Testimonial', 'factora' ),
			'priority' => 10,
		),
		'footer'      => array(
			'title'      => esc_html__( 'Footer', 'factora' ),
			'priority'   => 100,
			'capability' => 'edit_theme_options',
		),
		'mobile'      => array(
			'title'      => esc_html__( 'Mobile', 'factora' ),
			'priority'   => 100,
			'capability' => 'edit_theme_options',
		),
	);

	$sections = array(
		// Typography Section
		'body_typo'                    => array(
			'title'       => esc_html__( 'Body', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'heading_typo'                 => array(
			'title'       => esc_html__( 'Heading', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'header_typo'                  => array(
			'title'       => esc_html__( 'Header', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'button_typo'                  => array(
			'title'       => esc_html__( 'Button', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'footer_typo'                  => array(
			'title'       => esc_html__( 'Footer', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),

		// Styling Section
		'color_scheme'                 => array(
			'title'       => esc_html__( 'Color Scheme', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'styling',
		),

		// Header Sections
		'topbar'                       => array(
			'title'       => esc_html__( 'Topbar', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'header_logo'                  => array(
			'title'       => esc_html__( 'Header Logo', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'header_layout'                => array(
			'title'       => esc_html__( 'Header Layout', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'header_search'                => array(
			'title'       => esc_html__( 'Search', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'header_button'                => array(
			'title'       => esc_html__( 'Button', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'header_hotline'               => array(
			'title'       => esc_html__( 'Hotline', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),

		// Page Header Sections
		'page_header_site'             => array(
			'title'    => esc_html__( 'On Whole Site', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),
		'page_header_page'             => array(
			'title'    => esc_html__( 'On Page', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),
		'page_header_blog'             => array(
			'title'    => esc_html__( 'On Blog Page', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),
		'page_header_post'             => array(
			'title'    => esc_html__( 'On Post Page', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),
		'page_header_service'          => array(
			'title'    => esc_html__( 'On Service Page', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),
		'page_header_service_single'   => array(
			'title'    => esc_html__( 'On Service Single Page', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),
		'page_header_portfolio'        => array(
			'title'    => esc_html__( 'On Portfolio Page', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),
		'page_header_portfolio_single' => array(
			'title'    => esc_html__( 'On Portfolio Single Page', 'factora' ),
			'priority' => 10,
			'panel'    => 'page_header',
		),

		// Page Sections
		'404_page'                     => array(
			'title'       => esc_html__( '404 Page', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'page',
		),
		'coming_soon'                  => array(
			'title'       => esc_html__( 'Coming Soon', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'page',
		),

		// Blog Sections
		'blog_page'                    => array(
			'title'       => esc_html__( 'Blog Page', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'blog',
		),
		'single_post'                  => array(
			'title'       => esc_html__( 'Single Post', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'blog',
		),

		// Portfolio Sections
		'portfolio'                    => array(
			'title'       => esc_html__( 'Portfolio', 'factora' ),
			'description' => '',
			'panel'       => 'portfolio',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
		),
		'portfolio_single'             => array(
			'title'       => esc_html__( 'Single Portfolio', 'factora' ),
			'description' => '',
			'panel'       => 'portfolio',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
		),

		// Service Sections
		'service'                      => array(
			'title'       => esc_html__( 'Service', 'factora' ),
			'description' => '',
			'panel'       => 'service',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
		),
		'service_single'               => array(
			'title'       => esc_html__( 'Single Service', 'factora' ),
			'description' => '',
			'panel'       => 'service',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
		),

		// Service Sections
		'testimonial'                  => array(
			'title'       => esc_html__( 'Testimonial Layout', 'factora' ),
			'description' => '',
			'panel'       => 'testimonial',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
		),

		// Footer Sections
		'newsletter'                   => array(
			'title'       => esc_html__( 'Newsletter', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'footer',
		),
		'footer'                       => array(
			'title'       => esc_html__( 'Footer Layout', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'footer',
		),
		'copyright'                    => array(
			'title'       => esc_html__( 'Copyright', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'footer',
		),
		'backtotop'                    => array(
			'title'       => esc_html__( 'Back to Top', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'footer',
		),
		// Mobile
		'mobile_topbar'                => array(
			'title'       => esc_html__( 'Top Bar', 'factora' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'mobile',
		),
	);

	$fields = array(
		// Typography
		'body_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Body', 'factora' ),
			'section'  => 'body_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Rubik',
				'variant'        => '400',
				'font-size'      => '16px',
				'line-height'    => '1.6',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),
		'heading1_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 1', 'factora' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '600',
				'font-size'      => '60px',
				'line-height'    => '1.3',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),
		'heading2_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 2', 'factora' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'font-size'      => '40px',
				'line-height'    => '1.3',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),
		'heading3_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 3', 'factora' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'font-size'      => '30px',
				'line-height'    => '1.3',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),
		'heading4_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 4', 'factora' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'font-size'      => '24px',
				'line-height'    => '1.3',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),
		'heading5_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 5', 'factora' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'font-size'      => '18px',
				'line-height'    => '1.3',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),
		'heading6_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 6', 'factora' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'font-size'      => '16px',
				'line-height'    => '1.3',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),
		'menu_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Menu', 'factora' ),
			'section'  => 'header_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '16px',
				'color'          => '#000',
				'text-transform' => 'capitalize',
			),
		),
		'sub_menu_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Sub Menu', 'factora' ),
			'section'  => 'header_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '16px',
				'color'          => '#000',
				'text-transform' => 'capitalize',
			),
		),
		'button_typo'                  => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Button', 'factora' ),
			'section'  => 'button_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Montserrat',
				'variant'        => '700',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '13px',
				'color'          => '#000',
				'text-transform' => 'uppercase',
			),
		),
		'footer_text_typo'             => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Footer Text', 'factora' ),
			'section'  => 'footer_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Rubik',
				'variant'        => '400',
				'font-size'      => '16px',
				'line-height'    => '1.6',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#5b5b5a',
				'text-transform' => 'none',
			),
		),

		// Color Scheme
		'color_scheme'                 => array(
			'type'     => 'palette',
			'label'    => esc_html__( 'Base Color Scheme', 'factora' ),
			'default'  => '',
			'section'  => 'color_scheme',
			'priority' => 10,
			'choices'  => array(
				''        => array( '#f9c01d' ),
				'#4fa65c' => array( '#4fa65c' ),
				'#3065B8' => array( '#3065B8' ),
				'#8224e3' => array( '#8224e3' ),
				'#dd3333' => array( '#dd3333' ),
			),
		),
		'custom_color_scheme'          => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Custom Color Scheme', 'factora' ),
			'default'  => 0,
			'section'  => 'color_scheme',
			'priority' => 10,
		),
		'custom_color'                 => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Color', 'factora' ),
			'default'         => '',
			'section'         => 'color_scheme',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'custom_color_scheme',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'color_skin'                   => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Skin', 'factora' ),
			'section'  => 'color_scheme',
			'default'  => '',
			'priority' => 10,
			'choices'  => array(
				''      => esc_html__( 'Dark', 'factora' ),
				'light' => esc_html__( 'Light', 'factora' ),
			),
		),

		// Topbar
		'topbar'                       => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Enable Top Bar', 'factora' ),
			'default'  => '0',
			'section'  => 'topbar',
			'priority' => 10,
		),
		'custom_topbar'                => array(
			'type'            => 'custom',
			'section'         => 'topbar',
			'default'         => '<hr/>',
			'active_callback' => array(
				array(
					'setting'  => 'topbar',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'topbar_column'                => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Top Bar Column', 'factora' ),
			'section'         => 'topbar',
			'default'         => '2',
			'priority'        => 10,
			'description'     => esc_html__( 'Go to Appearance > Widgets > Topbar Column 1 and Topbar Column 2 to add widgets content.', 'factora' ),
			'choices'         => array(
				'1' => esc_html__( '1 Column', 'factora' ),
				'2' => esc_html__( '2 Columns', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'topbar',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'topbar_column_align'          => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Top Bar Align', 'factora' ),
			'section'         => 'topbar',
			'default'         => 'center',
			'priority'        => 10,
			'choices'         => array(
				'left'   => esc_html__( 'Left', 'factora' ),
				'right'  => esc_html__( 'Right', 'factora' ),
				'center' => esc_html__( 'Center', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'topbar',
					'operator' => '==',
					'value'    => '1',
				),
				array(
					'setting'  => 'topbar_column',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'topbar_bg'                    => array(
			'type'     => 'color',
			'label'    => esc_html__( 'Background Color', 'factora' ),
			'default'  => '',
			'section'  => 'topbar',
			'priority' => 10,
		),
		'topbar_color'                 => array(
			'type'     => 'color',
			'label'    => esc_html__( 'Text Color', 'factora' ),
			'default'  => '',
			'section'  => 'topbar',
			'priority' => 10,
		),
		'topbar_color_link'            => array(
			'type'     => 'color',
			'label'    => esc_html__( 'Link Color', 'factora' ),
			'default'  => '',
			'section'  => 'topbar',
			'priority' => 10,
		),

		// Logo
		'logo_type'                    => array(
			'type'    => 'radio',
			'label'   => esc_html__( 'Logo Type', 'factora' ),
			'default' => 'image',
			'section' => 'header_logo',
			'choices' => array(
				'image' => esc_html__( 'Image', 'factora' ),
				'svg'   => esc_html__( 'SVG', 'factora' ),
			),
		),
		'logo_svg'                     => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Logo SVG', 'factora' ),
			'section'         => 'header_logo',
			'description'     => esc_html__( 'Paste SVG code of your logo here', 'factora' ),
			'output'          => array(
				array(
					'element' => '.site-branding .logo',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'logo_type',
					'operator' => '==',
					'value'    => 'svg',
				),
			),
		),
		'logo'                         => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Logo', 'factora' ),
			'default'         => '',
			'section'         => 'header_logo',
			'active_callback' => array(
				array(
					'setting'  => 'logo_type',
					'operator' => '==',
					'value'    => 'image',
				),
			),
		),
		// Header Layout
		'header_layout'                => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Header Layout', 'factora' ),
			'section'  => 'header_layout',
			'default'  => '2',
			'priority' => 10,
			'choices'  => array(
				'1' => esc_html__( 'Header v1', 'factora' ),
				'2' => esc_html__( 'Header v2', 'factora' ),
				'3' => esc_html__( 'Header v3', 'factora' ),
				'4' => esc_html__( 'Header v4', 'factora' ),
			),
		),
		'header_layout_custom_field_1' => array(
			'type'     => 'custom',
			'section'  => 'header_layout',
			'default'  => '<hr/>',
			'priority' => 20,
		),
		'menu_extras'                  => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Menu Extras', 'factora' ),
			'section'         => 'header_layout',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'search' => esc_html__( 'Search', 'factora' ),
				'cart'   => esc_html__( 'Cart', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'menu_extras_2'                => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Menu Extras', 'factora' ),
			'section'         => 'header_layout',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'search' => esc_html__( 'Search', 'factora' ),
				'cart'   => esc_html__( 'Cart', 'factora' ),
				'button' => esc_html__( 'Button', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => '==',
					'value'    => '2',
				),
			),
		),
		'menu_extras_3'                => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Menu Extras', 'factora' ),
			'section'         => 'header_layout',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'search'  => esc_html__( 'Search', 'factora' ),
				'hotline' => esc_html__( 'Hotline', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => '==',
					'value'    => '3',
				),
			),
		),
		'menu_extras_4'                => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Menu Extras', 'factora' ),
			'section'         => 'header_layout',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'search' => esc_html__( 'Search', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => '==',
					'value'    => '4',
				),
			),
		),


		'header_sticky'                   => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Header Sticky', 'factora' ),
			'default'  => 0,
			'section'  => 'header_layout',
			'priority' => 100,
		),

		'search_view'      => array(
			'type'     => 'radio',
			'label'    => esc_html__( 'Search View', 'factora' ),
			'section'  => 'header_search',
			'default'  => 'icon',
			'priority' => 20,
			'choices'  => array(
				'icon' => esc_html__( 'Icon', 'factora' ),
				'form' => esc_html__( 'Form', 'factora' ),
			),
		),
		'search_view_text' => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Text', 'factora' ),
			'section'  => 'header_search',
			'default'  => esc_html__( 'Search...', 'factora' ),
			'priority' => 20,
		),

		'header_button_text' => array(
			'type'     => 'textarea',
			'label'    => esc_html__( 'Text', 'factora' ),
			'section'  => 'header_button',
			'default'  => esc_html__( 'Get in touch', 'factora' ),
			'priority' => 20,
		),
		'header_button_link' => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Link Url', 'factora' ),
			'section'  => 'header_button',
			'default'  => '',
			'priority' => 20,
		),

		'header_hotline_text'                         => array(
			'type'     => 'textarea',
			'label'    => esc_html__( 'Text', 'factora' ),
			'section'  => 'header_hotline',
			'default'  => '',
			'priority' => 20,
		),
		'header_hotline_phone'                        => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Phone Number', 'factora' ),
			'section'  => 'header_hotline',
			'default'  => '',
			'priority' => 20,
		),

		// Page Header
		'page_header'                                 => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_site',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'priority'    => 20,
			'default'     => 1,
		),
		'page_header_els'                             => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_site',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_1'                        => array(
			'type'            => 'custom',
			'section'         => 'page_header_site',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_align'                           => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_site',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_bg'                              => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_site',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_parallax'                        => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_site',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_color'                           => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_site',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_title_color'                     => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_site',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_br_color'                        => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_site',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_br_link_color'                   => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_site',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'custom_page_header_2'                        => array(
			'type'            => 'custom',
			'section'         => 'page_header_site',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_padding_top'                     => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_site',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_padding_bottom'                  => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_site',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		// Page Header Blog
		'page_header_blog'                            => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_blog',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'priority'    => 20,
			'default'     => 1,
		),
		'page_header_blog_els'                        => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_blog',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_blog_1'                   => array(
			'type'            => 'custom',
			'section'         => 'page_header_blog',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_blog_align'                      => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_blog',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_blog_bg'                         => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_blog',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_blog_parallax'                   => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_blog',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_blog_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_blog_color'                      => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_blog',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_blog_title_color'                => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_blog',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_blog_br_color'                   => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_blog',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_blog_br_link_color'              => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_blog',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_blog_header_2'                   => array(
			'type'            => 'custom',
			'section'         => 'page_header_blog',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_blog_padding_top'                => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_blog',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_blog_padding_bottom'             => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_blog',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_blog',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		// Page Header Post
		'page_header_post'                            => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_post',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'priority'    => 20,
			'default'     => 1,
		),
		'page_header_post_els'                        => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_post',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_post_1'                   => array(
			'type'            => 'custom',
			'section'         => 'page_header_post',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_post_align'                      => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_post',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_post_bg'                         => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_post',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_post_parallax'                   => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_post',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_post_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_post_color'                      => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_post',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_post_title_color'                => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_post',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_post_br_color'                   => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_post',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_post_br_link_color'              => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_post',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'custom_page_header_post_2'                   => array(
			'type'            => 'custom',
			'section'         => 'page_header_post',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_post_padding_top'                => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_post',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_post_padding_bottom'             => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_post',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_post',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		// Page Header Page
		'page_header_page'                            => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_page',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'priority'    => 20,
			'default'     => 1,
		),
		'page_header_page_els'                        => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_page',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_page_1'                   => array(
			'type'            => 'custom',
			'section'         => 'page_header_page',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_page_align'                      => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_page',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_page_bg'                         => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_page',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_page_parallax'                   => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_page',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
				array(
					'setting'  => 'page_header_page_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_page_color'                      => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_page',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_page_title_color'                => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_page',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_page_br_color'                   => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_page',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_page_br_link_color'              => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_page',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'custom_page_header_page_2'                   => array(
			'type'            => 'custom',
			'section'         => 'page_header_page',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_page_padding_top'                => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_page',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_page_padding_bottom'             => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_page',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		// Page Header Service
		'page_header_service'                         => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_service',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'priority'    => 20,
			'default'     => 1,
		),
		'page_header_service_els'                     => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_service',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_service_1'                => array(
			'type'            => 'custom',
			'section'         => 'page_header_service',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_service_align'                   => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_service',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_bg'                      => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_service',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_parallax'                => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_service',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_service_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_service_color'                   => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_service',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_title_color'             => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_service',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_br_color'                => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_service',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_br_link_color'           => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_service',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'custom_page_header_service_2'                => array(
			'type'            => 'custom',
			'section'         => 'page_header_page',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_service_padding_top'             => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_service',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_service_padding_bottom'          => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_service',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		// Page Header Service Single
		'page_header_service_single'                  => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_service_single',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'default'     => 1,
			'priority'    => 20,
		),
		'page_header_service_single_els'              => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_service_single',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_service_single_1'         => array(
			'type'            => 'custom',
			'section'         => 'page_header_service_single',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_service_single_align'            => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_service_single',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_single_bg'               => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_service_single',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_single_parallax'         => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_service_single',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_service_single_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_service_single_color'            => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_service_single',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_single_title_color'      => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_service_single',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_single_br_color'         => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_service_single',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_service_single_br_link_color'    => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_service_single',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'custom_page_header_service_single_2'         => array(
			'type'            => 'custom',
			'section'         => 'page_header_page',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_service_single_padding_top'      => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_service_single',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_service_single_padding_bottom'   => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_service_single',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_service_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),

		// Page Header Portfolio
		'page_header_portfolio'                       => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_portfolio',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'default'     => 1,
			'priority'    => 20,
		),
		'page_header_portfolio_els'                   => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_portfolio',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_portfolio_1'              => array(
			'type'            => 'custom',
			'section'         => 'page_header_portfolio',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_portfolio_align'                 => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_portfolio',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_bg'                    => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_portfolio',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_parallax'              => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_portfolio',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_portfolio_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_portfolio_color'                 => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_portfolio',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_title_color'           => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_portfolio',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_br_color'              => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_portfolio',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_br_link_color'         => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_portfolio',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'custom_page_header_portfolio_2'              => array(
			'type'            => 'custom',
			'section'         => 'page_header_page',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_portfolio_padding_top'           => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_portfolio',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_portfolio_padding_bottom'        => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_portfolio',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),

		// Page Header Portfolio Single
		'page_header_portfolio_single'                => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'factora' ),
			'section'     => 'page_header_portfolio_single',
			'description' => esc_html__( 'Enable to show a page header for whole site below the site header', 'factora' ),
			'default'     => 1,
			'priority'    => 20,
		),
		'page_header_portfolio_single_els'            => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Elements', 'factora' ),
			'section'         => 'page_header_portfolio_single',
			'default'         => array( 'breadcrumb', 'title' ),
			'priority'        => 20,
			'choices'         => array(
				'title'      => esc_html__( 'Title', 'factora' ),
				'breadcrumb' => esc_html__( 'BreadCrumb', 'factora' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'custom_page_header_portfolio_single_1'       => array(
			'type'            => 'custom',
			'section'         => 'page_header_portfolio_single',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_portfolio_single_align'          => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Text Center', 'factora' ),
			'section'         => 'page_header_portfolio_single',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_single_bg'             => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'page_header_portfolio_single',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_single_parallax'       => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Parallax', 'factora' ),
			'section'         => 'page_header_portfolio_single',
			'description'     => esc_html__( 'Check this option to enable parallax for the page header.', 'factora' ),
			'priority'        => 20,
			'default'         => '1',
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_portfolio_single_bg',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_portfolio_single_color'          => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'page_header_portfolio_single',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_single_title_color'    => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Title Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_portfolio_single',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_single_br_color'       => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_portfolio_single',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_portfolio_single_br_link_color'  => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Breadcrumb Link Color', 'factora' ),
			'default'         => '',
			'section'         => 'page_header_portfolio_single',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'custom_page_header_portfolio_single_2'       => array(
			'type'            => 'custom',
			'section'         => 'page_header_page',
			'default'         => '<hr/>',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_page',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_portfolio_single_padding_top'    => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Top', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_portfolio_single',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-top',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'page_header_portfolio_single_padding_bottom' => array(
			'type'            => 'slider',
			'label'           => esc_html__( 'Padding Bottom', 'factora' ),
			'transport'       => 'postMessage',
			'section'         => 'page_header_portfolio_single',
			'default'         => '50',
			'priority'        => 20,
			'choices'         => array(
				'min' => 10,
				'max' => 500,
			),
			'js_vars'         => array(
				array(
					'element'  => '.page-header',
					'property' => 'padding-bottom',
					'units'    => 'px',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_portfolio_single',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),

		// Page
		'404_page_image'                              => array(
			'type'     => 'image',
			'label'    => esc_html__( 'Image', 'factora' ),
			'section'  => '404_page',
			'default'  => '',
			'priority' => 10,
		),
		'404_page_title'                              => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Title', 'factora' ),
			'section'  => '404_page',
			'default'  => esc_html__( 'ohh! page not found', 'factora' ),
			'priority' => 10,
		),
		'404_page_description'                        => array(
			'type'     => 'textarea',
			'label'    => esc_html__( 'Description', 'factora' ),
			'section'  => '404_page',
			'default'  => esc_html__( 'It seems we can\'t find what you\'re looking for. perhaps searching can help', 'factora' ),
			'priority' => 10,
		),
		// Coming soon
		'coming_soon_background_image'                => array(
			'type'     => 'image',
			'label'    => esc_html__( 'Coming Soon Background Image', 'factora' ),
			'section'  => 'coming_soon',
			'default'  => '',
			'priority' => 10,
		),
		'coming_soon_newsletter'                      => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Newsletter', 'factora' ),
			'section'  => 'coming_soon',
			'default'  => 0,
			'priority' => 10,
		),
		'coming_soon_newsletter_form'                 => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Newsletter Form', 'factora' ),
			'section'         => 'coming_soon',
			'default'         => '[mc4wp_form id="279"]',
			'priority'        => 10,
			'description'     => esc_html__( 'Go to MailChimp for WP/Form to get shortcode', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'coming_soon_newsletter',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'show_coming_soon_socials'                    => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Socials', 'factora' ),
			'section'     => 'coming_soon',
			'default'     => 1,
			'description' => esc_html__( 'Display social sharing icons on Coming Soon Page', 'factora' ),
			'priority'    => 20,
		),
		'coming_soon_socials'                         => array(
			'type'            => 'repeater',
			'label'           => esc_html__( 'Socials', 'factora' ),
			'section'         => 'coming_soon',
			'priority'        => 60,
			'default'         => array(
				array(
					'link_url' => 'https://facebook.com/factora',
				),
				array(
					'link_url' => 'https://twitter.com/factora',
				),
			),
			'fields'          => array(
				'link_url' => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Social URL', 'factora' ),
					'description' => esc_html__( 'Enter the URL for this social', 'factora' ),
					'default'     => '',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'show_coming_soon_socials',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		// Blog
		'blog_view'                                   => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Blog View', 'factora' ),
			'section'  => 'blog_page',
			'default'  => 'list',
			'priority' => 10,
			'choices'  => array(
				'list' => esc_html__( 'List', 'factora' ),
				'grid' => esc_html__( 'Grid', 'factora' ),
			),
		),

		'blog_layout' => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Blog Layout', 'factora' ),
			'section'         => 'blog_page',
			'default'         => 'content-sidebar',
			'priority'        => 10,
			'description'     => esc_html__( 'Select default sidebar for the blog page.', 'factora' ),
			'choices'         => array(
				'content-sidebar' => esc_html__( 'Right Sidebar', 'factora' ),
				'sidebar-content' => esc_html__( 'Left Sidebar', 'factora' ),
				'full-content'    => esc_html__( 'Full Content', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'blog_view',
					'operator' => '==',
					'value'    => 'list',
				),
			),
		),

		'blog_entry_meta' => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Entry meta', 'factora' ),
			'section'  => 'blog_page',
			'default'  => array( 'author', 'date' ),
			'priority' => 10,
			'choices'  => array(
				'author' => esc_html__( 'Author', 'factora' ),
				'date'   => esc_html__( 'Date', 'factora' ),
				'cat'    => esc_html__( 'Category', 'factora' ),
			),
		),

		'blog_grid_columns' => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Columns', 'factora' ),
			'section'         => 'blog_page',
			'default'         => '3',
			'priority'        => 10,
			'description'     => esc_html__( 'Select default column for the blog grid.', 'factora' ),
			'choices'         => array(
				'3' => esc_html__( '3 Columns', 'factora' ),
				'2' => esc_html__( '2 Columns', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'blog_view',
					'operator' => '==',
					'value'    => 'grid',
				),
			),
		),

		'excerpt_length_post' => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Limit content blog', 'factora' ),
			'section'         => 'blog_page',
			'default'         => '50',
			'active_callback' => array(
				array(
					'setting'  => 'blog_view',
					'operator' => '!=',
					'value'    => 'grid',
				),
			),
			'priority'        => 10,
		),

		'title_blog' => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Title Blog', 'factora' ),
			'section'  => 'blog_page',
			'default'  => '',
			'priority' => 10,
		),

		'blog_cat_filter' => array(
			'type'     => 'toggle',
			'default'  => 0,
			'label'    => esc_html__( 'Categories Filter', 'factora' ),
			'section'  => 'blog_page',
			'priority' => 10,
		),

		'blog_categories_numbers' => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Limit categories blog', 'factora' ),
			'section'         => 'blog_page',
			'default'         => 5,
			'active_callback' => array(
				array(
					'setting'  => 'blog_cat_filter',
					'operator' => '==',
					'value'    => 1,
				),
			),
			'priority'        => 10,
		),

		'blog_categories'    => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Categories slug', 'factora' ),
			'section'         => 'blog_page',
			'default'         => '',
			'priority'        => 10,
			'description'     => esc_html__( 'Enter categories slug you want to display. Each slug is separated by comma character ",". If empty, it will display default', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'blog_cat_filter',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		// Single Blog
		'single_post_layout' => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Single Post Layout', 'factora' ),
			'section'     => 'single_post',
			'default'     => 'content-sidebar',
			'priority'    => 10,
			'description' => esc_html__( 'Select default sidebar for the blog single.', 'factora' ),
			'choices'     => array(
				'content-sidebar' => esc_html__( 'Right Sidebar', 'factora' ),
				'sidebar-content' => esc_html__( 'Left Sidebar', 'factora' ),
				'full-content'    => esc_html__( 'Full Content', 'factora' ),
			),
		),

		'single_post_entry_meta' => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Entry meta', 'factora' ),
			'section'  => 'single_post',
			'default'  => array( 'author', 'date' ),
			'priority' => 10,
			'choices'  => array(
				'author' => esc_html__( 'Author', 'factora' ),
				'date'   => esc_html__( 'Date', 'factora' ),
				'cat'    => esc_html__( 'Category', 'factora' ),
			),
		),

		'show_featured_image' => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Featured Image', 'factora' ),
			'description' => esc_html__( 'Check this option to show featured image in the single post page.', 'factora' ),
			'section'     => 'single_post',
			'default'     => 1,
			'priority'    => 10,
		),

		'show_post_social_share' => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Socials Share', 'factora' ),
			'description' => esc_html__( 'Check this option to show socials share in the single post page.', 'factora' ),
			'section'     => 'single_post',
			'default'     => 0,
			'priority'    => 10,
		),

		'post_socials_share' => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Socials Share', 'factora' ),
			'section'         => 'single_post',
			'default'         => array( 'facebook', 'twitter', 'tumblr', 'instagram' ),
			'choices'         => array(
				'facebook'  => esc_html__( 'Facebook', 'factora' ),
				'twitter'   => esc_html__( 'Twitter', 'factora' ),
				'pinterest' => esc_html__( 'Pinterest', 'factora' ),
				'linkedin'  => esc_html__( 'Linkedin', 'factora' ),
				'instagram' => esc_html__( 'Instagram', 'factora' ),
				'vimeo'     => esc_html__( 'Vimeo', 'factora' ),
				'share'     => esc_html__( 'Share', 'factora' ),
			),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'show_post_social_share',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		'show_navigation' => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Show navigation', 'factora' ),
			'section'  => 'single_post',
			'default'  => 0,
			'priority' => 10,
		),

		'show_author_box' => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Show Author Box', 'factora' ),
			'section'  => 'single_post',
			'default'  => 0,
			'priority' => 10,
		),

		// Relatest Post
		'related_posts'   => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Related Post', 'factora' ),
			'description' => esc_html__( 'Check this option to show related post in the single post page.', 'factora' ),
			'section'     => 'single_post',
			'default'     => 0,
			'priority'    => 10,
		),

		'related_posts_title' => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Title for related post', 'factora' ),
			'section'         => 'single_post',
			'default'         => esc_html__( 'Related Posts', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'related_posts',
					'operator' => '==',
					'value'    => 1,
				),
			),
			'priority'        => 10,
		),

		'related_posts_numbers' => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Display number post', 'factora' ),
			'section'         => 'single_post',
			'default'         => '3',
			'active_callback' => array(
				array(
					'setting'  => 'related_posts',
					'operator' => '==',
					'value'    => 1,
				),
			),
			'priority'        => 10,
		),

		'show_carousel_related_posts' => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Show Carousel Post', 'factora' ),
			'section'         => 'single_post',
			'default'         => '2',
			'active_callback' => array(
				array(
					'setting'  => 'related_posts',
					'operator' => '==',
					'value'    => 1,
				),
			),
			'priority'        => 10,
		),

		'related_posts_numbers_show' => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Display number post show in carousel', 'factora' ),
			'section'         => 'single_post',
			'default'         => '3',
			'active_callback' => array(
				array(
					'setting'  => 'show_carousel_related_posts',
					'operator' => '==',
					'value'    => 1,
				),
			),
			'priority'        => 10,
		),

		//Portfolio
		'portfolio_layout'           => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Portfolio Layout', 'factora' ),
			'section'  => 'portfolio',
			'default'  => 'grid',
			'priority' => 10,
			'choices'  => array(
				'grid'       => esc_html__( 'Grid', 'factora' ),
				'full-width' => esc_html__( 'Full Width', 'factora' ),
				'listing'    => esc_html__( 'Listing', 'factora' ),
			),
		),
		'portfolio_columns'          => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Portfolio Columns', 'factora' ),
			'section'         => 'portfolio',
			'default'         => '3',
			'priority'        => 10,
			'choices'         => array(
				3 => esc_html__( '3 Columns', 'factora' ),
				4 => esc_html__( '4 Columns', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_layout',
					'operator' => '!=',
					'value'    => 'listing',
				),
			),
		),

		'portfolio_cats_filters'          => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Portfolio Categories Filters', 'factora' ),
			'priority' => 10,
			'default'  => '1',
			'section'  => 'portfolio',
		),
		'portfolio_title'                 => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Portfolio Title', 'factora' ),
			'priority'        => 10,
			'default'         => 'Our Projects',
			'section'         => 'portfolio',
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_cats_filters',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'portfolio_text_filter_all_items' => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Text view all', 'factora' ),
			'priority'        => 10,
			'default'         => 'View all',
			'section'         => 'portfolio',
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_cats_filters',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'portfolio_cat_number'            => array(
			'type'            => 'number',
			'label'           => esc_html__( 'Categorize  number', 'factora' ),
			'priority'        => 10,
			'default'         => '10',
			'section'         => 'portfolio',
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_cats_filters',
					'operator' => '==',
					'value'    => '1',
				),
			),

		),
		'portfolio_categories'            => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Categories slug', 'factora' ),
			'section'         => 'blog_page',
			'default'         => '',
			'priority'        => 10,
			'description'     => esc_html__( 'Enter categories slug you want to display. Each slug is separated by comma character ",". If empty, it will display default', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_cats_filters',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'portfolio_title_length'          => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Portfolio Title Length', 'factora' ),
			'section'  => 'portfolio',
			'default'  => 15,
			'priority' => 10,
		),
		'portfolio_excerpt_length'        => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Portfolio Excerpt Length', 'factora' ),
			'section'  => 'portfolio',
			'default'  => 30,
			'priority' => 10,
		),
		'portfolio_pagination'            => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Pagination', 'factora' ),
			'priority' => 10,
			'default'  => '1',
			'section'  => 'portfolio',

		),
		'portfolio_pagination_style'      => array(
			'type'            => 'radio',
			'label'           => esc_html__( 'Pagination style', 'factora' ),
			'priority'        => 10,
			'default'         => '1',
			'section'         => 'portfolio',
			'choices'         => array(
				'1' => esc_html__( 'Number', 'factora' ),
				'2' => esc_html__( 'Load more', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_pagination',
					'operator' => '==',
					'value'    => '1',
				),
			),

		),

		// Single Portfolio
		'portfolio_single_nav'            => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Navigation', 'factora' ),
			'default'  => 1,
			'section'  => 'portfolio_single',
			'priority' => 10,
		),
		'portfolio_single_project_text'   => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Text Project Link', 'factora' ),
			'default'         => '',
			'section'         => 'portfolio_single',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_single_nav',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'portfolio_single_project_link'        => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Go to Project Link', 'factora' ),
			'default'         => '',
			'section'         => 'portfolio_single',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_single_nav',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'portfolio_related'               => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Related', 'factora' ),
			'default'  => 1,
			'section'  => 'portfolio_single',
			'priority' => 10,
		),
		'portfolio_related_maximum_items' => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Maximum items', 'factora' ),
			'default'         => '10',
			'section'         => 'portfolio_single',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_related',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),


		//Service

		'service_columns' => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Service Columns', 'factora' ),
			'section'         => 'service',
			'default'         => '3',
			'priority'        => 10,
			'choices'         => array(
				3 => esc_html__( '3 Columns', 'factora' ),
				4 => esc_html__( '4 Columns', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'service_layout',
					'operator' => '!=',
					'value'    => 'listing',
				),
			),
		),


		'service_title_length'          => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Service Title Length', 'factora' ),
			'section'  => 'service',
			'default'  => 15,
			'priority' => 10,
		),
		'service_excerpt_length'        => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Service Title Length', 'factora' ),
			'section'  => 'service',
			'default'  => 30,
			'priority' => 10,
		),
		'service_pagination'            => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Pagination', 'factora' ),
			'priority' => 10,
			'default'  => '1',
			'section'  => 'service',

		),
		'service_pagination_style'      => array(
			'type'            => 'radio',
			'label'           => esc_html__( 'Pagination style', 'factora' ),
			'priority'        => 10,
			'default'         => '1',
			'section'         => 'service',
			'choices'         => array(
				'1' => esc_html__( 'Number', 'factora' ),
				'2' => esc_html__( 'Load more', 'factora' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'service_pagination',
					'operator' => '==',
					'value'    => '1',
				),
			),

		),

		// Single Service
		'single_service_layout'         => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Single Layout', 'factora' ),
			'section'     => 'service_single',
			'default'     => 'sidebar-content',
			'priority'    => 10,
			'description' => esc_html__( 'Select default sidebar for the blog page.', 'factora' ),
			'choices'     => array(
				'content-sidebar' => esc_html__( 'Right Sidebar', 'factora' ),
				'sidebar-content' => esc_html__( 'Left Sidebar', 'factora' ),
				'full-content'    => esc_html__( 'Full Content', 'factora' ),
			),
		),
		'service_single_nav'            => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Navigation', 'factora' ),
			'default'  => 1,
			'section'  => 'service_single',
			'priority' => 10,
		),


		// Testimonial
		'testimonial_title'             => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Title', 'factora' ),
			'section'  => 'testimonial',
			'default'  => esc_html__( 'Testimonial', 'factora' ),
			'priority' => 10,
		),
		'testimonial_excerpt_length'    => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Limit Content', 'factora' ),
			'section'  => 'testimonial',
			'default'  => '50',
			'priority' => 10,
		),
		'testimonial_icon'               => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Show Icon', 'factora' ),
			'default'  => 1,
			'section'  => 'testimonial',
			'priority' => 10,
		),

		// Newsletter Footer
		'footer_newsletter'             => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Newsletter', 'factora' ),
			'section'  => 'newsletter',
			'default'  => '0',
			'priority' => 10,
		),
		'footer_newsletter_title'       => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Newsletter Text', 'factora' ),
			'section'         => 'newsletter',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_newsletter',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'footer_newsletter_description' => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Newsletter Text', 'factora' ),
			'section'         => 'newsletter',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_newsletter',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'footer_newsletter_form'        => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Newsletter Form', 'factora' ),
			'section'         => 'newsletter',
			'default'         => '[mc4wp_form id="279"]',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_newsletter',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		// Footer
		'footer_widget'                 => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Footer Widgets', 'factora' ),
			'section'  => 'footer',
			'default'  => '0',
			'priority' => 10,
		),
		'footer_widget_columns'         => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Footer Columns', 'factora' ),
			'section'         => 'footer',
			'default'         => '3',
			'priority'        => 20,
			'choices'         => array(
				'2' => esc_html__( '2 Columns', 'factora' ),
				'3' => esc_html__( '3 Columns', 'factora' ),
				'4' => esc_html__( '4 Columns', 'factora' ),
			),
			'description'     => esc_html__( 'Go to Appearance > Widgets > Footer 1, 2, 3, 4 to add widgets content.', 'factora' ),
			'active_callback' => array(
				array(
					'setting'  => 'footer_widget',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'footer_widget_custom'                => array(
			'type'            => 'custom',
			'section'         => 'footer',
			'default'         => '<hr/>',
			'priority'        => 20,
		),
		'footer_bg'                              => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Background Image', 'factora' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 20,
		),
		'footer_bg_overlay'                           => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color Overlay', 'factora' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 20,
			'choices'         => array(
				'alpha' => true,
			),
		),
		'footer_color'         => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Footer Color', 'factora' ),
			'section'         => 'footer',
			'default'         => 'dark',
			'priority'        => 20,
			'choices'         => array(
				'dark' => esc_html__( 'Dark', 'factora' ),
				'light' => esc_html__( 'Light', 'factora' ),
			),
		),

		// Copyright
		'footer_copyright'              => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Copyright', 'factora' ),
			'section'  => 'copyright',
			'default'  => '0',
			'priority' => 10,
		),
		'footer_copyright_text'         => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Footer Copyright', 'factora' ),
			'description'     => esc_html__( 'Shortcodes are allowed', 'factora' ),
			'section'         => 'copyright',
			'default'         => esc_html__( '&copy; 2019 Factora. All Rights Reserved', 'factora' ),
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'footer_copyright',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'footer_copyright_menu'              => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Footer Menu', 'factora' ),
			'section'  => 'copyright',
			'default'  => '0',
			'priority' => 10,
		),

		// Back to top
		'back_to_top'                   => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Back to Top', 'factora' ),
			'section'  => 'backtotop',
			'default'  => 0,
			'priority' => 10,
		),

		// Mobile
		'topbar_mobile'                 => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Enable Top Bar', 'factora' ),
			'section'  => 'mobile_topbar',
			'default'  => 0,
			'priority' => 10,
		),
		'topbar_mobile_align'           => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Enable Align Center', 'factora' ),
			'section'         => 'mobile_topbar',
			'default'         => 1,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'topbar_mobile',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

	);

	$settings['panels']   = apply_filters( 'factora_customize_panels', $panels );
	$settings['sections'] = apply_filters( 'factora_customize_sections', $sections );
	$settings['fields']   = apply_filters( 'factora_customize_fields', $fields );

	return $settings;
}

$factora_customize = new Factora_Customize( factora_customize_settings() );