<?php
/**
 * Custom functions for post
 *
 * @package Factora
 */

if ( ! function_exists( 'factora_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function factora_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
		/* translators: %s: post date. */
			esc_html_x( 'Posted on %s', 'post date', 'factora' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'factora_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function factora_posted_by() {
		$byline = sprintf(
		/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'factora' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'factora_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function factora_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'factora' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'factora' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'factora' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'factora' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
					/* translators: %s: post title */
						esc_html__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'factora' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
				/* translators: %s: Name of current post. Only visible to screen readers */
					esc_html__( 'Edit <span class="screen-reader-text">%s</span>', 'factora' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'factora_post_thumbnail' ) ) :

	function factora_post_thumbnail( $size = 'thumbnail' ) {
		$html_img = get_the_post_thumbnail( get_the_ID(), $size );

		if ( ! has_post_thumbnail() ) : return; endif;

		if ( is_single() ) :
			if ( ! intval( factora_get_option( 'show_featured_image' ) ) ): return; endif;
		endif;

		if ( ! is_singular( 'post' ) ) :
			$img = sprintf( '<a href="%s" class="post-thumbnail">%s </a>', esc_url( get_the_permalink() ), $html_img );
		else:
			$img = sprintf( '<div class="post-thumbnail">%s</div>', $html_img );
		endif;

		echo sprintf( '<div class="factora-post__entry-thumbnail">%s</div>', $img );
	}
endif;

if ( ! function_exists( 'factora_post_entry_meta' ) ) :
	/**
	 * Check entry meta
	 */

	function factora_post_entry_meta() {

		$metas = factora_get_option( 'single_post_entry_meta' );

		if ( factora_is_blog() ) {
			$metas = factora_get_option( 'blog_entry_meta' );
		}

		if ( empty( $metas ) ) {
			return;
		}

		$meta = array();

		if ( in_array( 'author', $metas ) ) {
			$meta[] = sprintf( '<div class="meta author">' . esc_html__( 'By ', 'factora' ) . ' <span class="name-author"><a href="' . esc_attr( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">%s</a></span></div>', esc_html( get_the_author() ) );
		}

		if ( in_array( 'cat', $metas ) ) {
			$category = get_the_terms( get_the_ID(), 'category' );

			$cat_html = '';

			if ( ! is_wp_error( $category ) && $category ) {
				$cat_html = sprintf(
					'<a href="%s" class="cat-links">%s</a>',
					esc_url( get_term_link( $category[0], 'category' ) ),
					esc_html( $category[0]->name )
				);
			}

			if ( $cat_html ) {
				$meta[] = sprintf( '<div class="meta cat">%s</div>', $cat_html );
			}
		}

		if ( in_array( 'date', $metas ) ) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

			$time_string = sprintf(
				$time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() )
			);
			$meta[]      = ! ( is_single() ) ? sprintf( '<div class="meta date"><a href="%s">%s</a></div>', esc_url( get_permalink() ), $time_string ) : sprintf( '<div class="meta date">%s</div>', $time_string );
		}


		echo '<div class="factora-post__entry-meta">' . implode( '', $meta ) . '</div> ';
	}
endif;

if ( ! function_exists( 'factora_title' ) ) :
	function factora_title() {
		if ( is_singular() && ! is_page() ) :
			the_title( '<h1 class="title title-single">', '</h1>' );
		else:
			the_title( '<h2 class="title title-post"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );
		endif;
	}
endif;

if ( ! function_exists( 'factora_single_post_entry_footer' ) ):
	/**
	 * Check entry footer single blog
	 */
	function factora_single_post_entry_footer() {
		$socials = factora_get_option( 'post_socials_share' );

		if ( ! is_singular( 'post' ) || ( empty( $socials ) && has_tag() == false ) || intval( factora_get_option( 'show_post_social_share' ) ) == 0 && has_tag() == false ) {
			return;
		} else {
			echo '<div class="factora-post__entry-footer">';
			if ( intval( factora_get_option( 'show_post_social_share' ) ) == 0 || empty( $socials ) ) {
				echo '<div class="full-width">';
			}
			echo '<div class="side-width">';
			if ( has_tag() ) :
				the_tags( '<div class="factora-post__tag-list"><span class="list-tags">' . esc_html__( 'Tags: ', 'factora' ) . '</span>', ', ', '</div>' );
			endif;
			echo '</div>';
			if ( intval( factora_get_option( 'show_post_social_share' ) ) == 0 || empty( $socials ) ) {
				echo '</div>';
			}
			if ( function_exists( 'factora_addons_share_link_socials' ) && intval( factora_get_option( 'show_post_social_share' ) ) && ( ! empty( $socials ) ) ) {
				echo '<div class="side-width">';
				echo '<div class="factora-post__socials-share">';
				echo esc_html__( 'Share:', 'factora' );
				echo factora_addons_share_link_socials( $socials, get_the_title(), get_the_permalink(), get_the_post_thumbnail() );
				echo '</div>';
				echo '</div>';
			};
			echo '</div>';
		}
	}
endif;

if ( ! function_exists( 'factora_author_box' ) ) :
	/**
	 * Get author box
	 *
	 * @since  1.0
	 *
	 */
	function factora_author_box() {
		if ( factora_get_option( 'show_author_box' ) == 0 ) {
			return;
		}

		if ( ! get_the_author_meta( 'description' ) ) {
			return;
		}

		if ( is_singular( 'portfolio' ) || is_singular( 'service' ) || is_singular( 'testimonial' ) ) {
			return;
		}

		?>
        <div class="factora-post__box-author">
            <div class="factora-post__avatar">
				<?php echo get_avatar( get_the_author_meta( 'ID' ), 80 ); ?>
            </div>
            <div class="factora-post__content">
                <h3 class="title"><?php the_author_meta( 'display_name' ); ?>
                    <span><?php esc_html_e( 'Author', 'factora' ) ?></span></h3>
                <div class="desc">
					<?php the_author_meta( 'description' ); ?>
                </div>
            </div>
        </div>
		<?php
	}
endif;

if ( ! function_exists( 'factora_content_limit' ) ) :
	/**
	 * Prints content limit.
	 */
	function factora_content_limit( $num_words, $more = "&hellip;" ) {
		$content = get_the_excerpt();

		// Remove inline styles / scripts
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		// Truncate $content to $max_char
		$content = wp_trim_words( $content, $num_words );

		if ( $more ) {
			echo sprintf(
				'<p>%s <a href="%s" class="more-link" title="%s">%s</a></p>',
				$content,
				get_permalink(),
				sprintf( esc_html__( 'Continue reading &quot;%s&quot;', 'factora' ), the_title_attribute( 'echo=0' ) ),
				esc_html( $more )
			);
		} else {
			echo sprintf( '<div class="factora-post__entry-content">%s</div>', $content );
		}
	}
endif;


if ( ! function_exists( 'factora_title_limit' ) ) :
	/**
	 * Prints content limit.
	 */
	function factora_title_limit( $num_words ) {
		$title = get_the_title();

		// Remove inline styles / scripts
		$title = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $title ) );

		// Truncate $content to $max_char
		$title = wp_trim_words( $title, $num_words );

		return $title;
	}
endif;

if ( ! function_exists( 'factora_post_entry_content' ) ) :

	function factora_post_entry_content() {
		$excerpt_length = intval( factora_get_option( 'excerpt_length_post' ) );

		if ( $excerpt_length >= 30 ) {
			$excerpt_length = 20;
		}

		factora_content_limit( $excerpt_length, '' );

	}
endif;

if ( ! function_exists( 'factora_testimonial_entry_content' ) ) :

	function factora_testimonial_entry_content() {
		$textimonial_excerpt_length = intval( factora_get_option( 'testimonial_excerpt_length' ) );

		if ( $textimonial_excerpt_length >= 30 ) {
			$textimonial_excerpt_length = 30;
		}

		factora_content_limit( $textimonial_excerpt_length, '' );

	}
endif;

if ( ! function_exists( 'factora_is_blog' ) ) :
	/**
	 * Check is blog
	 *
	 * @since  1.0
	 */
	function factora_is_blog() {


		if ( ( is_archive() || is_author() || is_category() || is_home() || is_tag() ) && 'post' == get_post_type() ) {
			return true;
		}

		return false;
	}

endif;

if ( ! function_exists( 'factora_is_catalog' ) ) :
	/**
	 * Check is blog
	 *
	 * @since  1.0
	 */
	function factora_is_catalog() {


		if ( function_exists( 'is_shop' ) && ( is_shop() || is_product_category() || is_product_tag() ) ) {
			return true;
		}

		return false;
	}

endif;

if ( ! function_exists( 'factora_post_taxs_list' ) ) :
	function factora_post_taxs_list( $taxonomy = 'category' ) {

		$term_id   = 0;
		$cats      = $output = '';
		$found     = false;
		$number    = intval( factora_get_option( 'blog_categories_numbers' ) );
		$cats_slug = wp_kses_post( factora_get_option( 'blog_categories' ) );
		$id        = 'factora-taxs-list';

		if ( is_tax( $taxonomy ) || is_category() ) {

			$queried_object = get_queried_object();
			if ( $queried_object ) {
				$term_id = $queried_object->term_id;
			}
		}

		if ( $cats_slug ) {
			$cats_slug = explode( ',', $cats_slug );

			foreach ( $cats_slug as $slug ) {
				$cat = get_term_by( 'slug', $slug, $taxonomy );

				if ( $cat ) {
					$cat_selected = '';
					if ( $cat->term_id == $term_id ) {
						$cat_selected = 'selected';
						$found        = true;
					}

					$cats .= sprintf( '<li><a href="%s" class="%s">%s</a></li>', esc_url( get_term_link( $cat ) ), esc_attr( $cat_selected ), esc_html( $cat->name ) );
				}
			}

		} else {
			$args = array(
				'number'  => $number,
				'orderby' => 'count',
				'order'   => 'DESC',

			);

			$categories = get_terms( $taxonomy, $args );
			if ( ! is_wp_error( $categories ) && $categories ) {
				foreach ( $categories as $cat ) {
					$cat_selected = '';
					if ( $cat->term_id == $term_id ) {
						$cat_selected = 'selected';
						$found        = true;
					}

					$cats .= sprintf( '<li><a href="%s" class="%s">%s</a></li>', esc_url( get_term_link( $cat ) ), esc_attr( $cat_selected ), esc_html( $cat->name ) );
				}
			}
		}

		$cat_selected = $found ? '' : 'selected';

		if ( $cats ) {
			$url     = get_page_link( get_option( 'page_for_posts' ) );
			$btn_all = esc_html__( 'All categories', 'factora' );
			if ( 'posts' == esc_html( get_option( 'show_on_front' ) ) ) {
				$url = home_url();
			}

			$output = sprintf(
				'<ul>' .
				'<li><a href="%s" class="%s">%s</a></li>' .
				'%s' .
				'</ul>',
				esc_url( $url ),
				esc_attr( $cat_selected ),
				$btn_all,
				$cats
			);
		}

		if ( $output ) {
			$output = apply_filters( 'factora_tax_html', $output );
			printf( '<div id="%s" class="factora-post__taxs-list">%s</div>', esc_attr( $id ), $output );
		}

	}
endif;

if ( ! function_exists( 'factora_menu_icon' ) ) :
	/**
	 * Get menu icon
	 */
	function factora_menu_icon() {
		printf(
			'<span id="factora-navbar-toggle" class="navbar-icon">
					<i class="icon-menu"></i>
				</span>'
		);
	}
endif;

?>